@@ -1,7 +1,6 @@
 import click
 import pynput.keyboard as kb
 from keyboard import is_pressed
-from lash.executor import playbp
 
 
 @click.command(help='hold a keyboard key')
@@ -11,10 +10,6 @@ def keyhold(key):
     print('initialized, f4 to start, f3 to stop')
     while True:
         if is_pressed('f4'):
-            try:
-                playbp()
-            except:
-                pass
             print('[== -- *typing* -- ==]')
             break
     try:
